@@ -68,7 +68,7 @@ impl Hash for Sha1 {
         }
     }
 
-    fn box_clone(&self) -> Box<Hash> {
+    fn box_clone(&self) -> Box<dyn Hash> {
         Box::new(self.clone())
     }
 }
