@@ -18,6 +18,8 @@ pub fn convert_gmpz_to_buffer(mut mpz: __mpz_struct) -> Box<[u8]> {
     }
 }
 
+/// Convert the buffer to an mpz number.
+/// This inits the mpz number. Take care not to init twice!
 pub fn convert_buffer_to_gmpz(buf: &[u8]) -> __mpz_struct {
     unsafe {
         let mut ret = zeroed();
@@ -36,7 +38,7 @@ pub fn write_gmpz_into_slice(
         if nettle_mpz_sizeinbase_256_u(&mut mpz as *mut _) > slice.len() {
             __gmpz_clear(&mut mpz);
 
-            Err(Error::InvalidArgument { argument_name: arg }.into())
+            Err(Error::InvalidArgument { argument_name: arg })
         } else {
             nettle_mpz_get_str_256(slice.len(), slice.as_mut_ptr(), &mut mpz);
             __gmpz_clear(&mut mpz);
