@@ -3,6 +3,11 @@
 
 #![warn(missing_docs)]
 
+// Allow Struct { field: field }
+#![allow(clippy::redundant_field_names)]
+// Allow module name repetition, e.g. modname::modname
+#![allow(clippy::module_inception)]
+
 extern crate libc;
 extern crate nettle_sys;
 extern crate getrandom;
