@@ -19,42 +19,42 @@ pub trait Pkcs1Hash: Hash {
 }
 
 /// ASN.1 OID for MD2
-pub const ASN1_OID_MD2: &'static [u8] = &[
+pub const ASN1_OID_MD2: &[u8] = &[
     0x30, 0x20, 0x30, 0x0c, 0x06, 0x08, 0x2a, 0x86, 0x48, 0x86, 0xf7, 0x0d,
     0x02, 0x02, 0x05, 0x00, 0x04, 0x10,
 ];
 /// ASN.1 OID for MD5
-pub const ASN1_OID_MD5: &'static [u8] = &[
+pub const ASN1_OID_MD5: &[u8] = &[
     0x30, 0x20, 0x30, 0x0c, 0x06, 0x08, 0x2a, 0x86, 0x48, 0x86, 0xf7, 0x0d,
     0x02, 0x05, 0x05, 0x00, 0x04, 0x10,
 ];
 /// ASN.1 OID for RipeMD160
-pub const ASN1_OID_RIPEMD160: &'static [u8] = &[
+pub const ASN1_OID_RIPEMD160: &[u8] = &[
     0x30, 0x21, 0x30, 0x09, 0x06, 0x05, 0x2B, 0x24, 0x03, 0x02, 0x01, 0x05,
     0x00, 0x04, 0x14,
 ];
 /// ASN.1 OID for SHA1
-pub const ASN1_OID_SHA1: &'static [u8] = &[
+pub const ASN1_OID_SHA1: &[u8] = &[
     0x30, 33, 0x30, 9, 0x06, 5, 0x2b, 0x0e, 0x03, 0x02, 0x1a, 0x05, 0, 0x04,
     20,
 ];
 /// ASN.1 OID for SHA224
-pub const ASN1_OID_SHA224: &'static [u8] = &[
+pub const ASN1_OID_SHA224: &[u8] = &[
     0x30, 0x2D, 0x30, 0x0D, 0x06, 0x09, 0x60, 0x86, 0x48, 0x01, 0x65, 0x03,
     0x04, 0x02, 0x04, 0x05, 0x00, 0x04, 0x1C,
 ];
 /// ASN.1 OID for SHA256
-pub const ASN1_OID_SHA256: &'static [u8] = &[
+pub const ASN1_OID_SHA256: &[u8] = &[
     0x30, 49, 0x30, 13, 0x06, 9, 0x60, 0x86, 0x48, 0x01, 0x65, 0x03, 0x04,
     0x02, 0x01, 0x05, 0, 0x04, 32,
 ];
 /// ASN.1 OID for SHA384
-pub const ASN1_OID_SHA384: &'static [u8] = &[
+pub const ASN1_OID_SHA384: &[u8] = &[
     0x30, 0x41, 0x30, 0x0D, 0x06, 0x09, 0x60, 0x86, 0x48, 0x01, 0x65, 0x03,
     0x04, 0x02, 0x02, 0x05, 0x00, 0x04, 0x30,
 ];
 /// ASN.1 OID for SHA512
-pub const ASN1_OID_SHA512: &'static [u8] = &[
+pub const ASN1_OID_SHA512: &[u8] = &[
     0x30, 81, 0x30, 13, 0x06, 9, 0x60, 0x86, 0x48, 0x01, 0x65, 0x03, 0x04,
     0x02, 0x03, 0x05, 0, 0x04, 64,
 ];
@@ -139,7 +139,7 @@ pub fn sign_digest_pkcs1<R: Random>(
         } else {
             __gmpz_clear(&mut sig);
 
-            Err(Error::SigningFailed.into())
+            Err(Error::SigningFailed)
         }
     }
 }
@@ -230,7 +230,7 @@ pub fn encrypt_pkcs1<R: Random>(
         } else {
             __gmpz_clear(&mut out);
 
-            Err(Error::EncryptionFailed.into())
+            Err(Error::EncryptionFailed)
         }
     }
 }
@@ -243,8 +243,7 @@ pub fn encrypt_pkcs1<R: Random>(
 ///
 /// # Errors
 ///
-/// Returns `InvalidArgument` if `ciphertext` is of a different size
-/// than `public`'s modulo, or if `plaintext`'s size is greater or
+/// Returns `InvalidArgument` if `plaintext`'s size is greater or
 /// equal than `public`'s modulo.
 pub fn decrypt_pkcs1<R: Random>(
     public: &PublicKey,
@@ -253,10 +252,6 @@ pub fn decrypt_pkcs1<R: Random>(
     ciphertext: &[u8],
     plaintext: &mut [u8],
 ) -> Result<()> {
-    if ciphertext.len() != public.modulo_bytes {
-        return Err(Error::invalid_argument("ciphertext"));
-    }
-
     if plaintext.len() >= public.modulo_bytes {
         return Err(Error::invalid_argument("plaintext"));
     }
@@ -300,19 +295,13 @@ pub fn decrypt_pkcs1<R: Random>(
 ///
 /// # Errors
 ///
-/// Returns `InvalidArgument` if `ciphertext` is of a different size
-/// than `public`'s modulo.  Returns `DecryptionFailed` if the
-/// decryption failed.
+/// Returns `DecryptionFailed` if the decryption failed.
 pub fn decrypt_pkcs1_insecure<R: Random>(
     public: &PublicKey,
     private: &PrivateKey,
     random: &mut R,
     ciphertext: &[u8],
 ) -> Result<Box<[u8]>> {
-    if ciphertext.len() != public.modulo_bytes {
-        return Err(Error::invalid_argument("ciphertext"));
-    }
-
     unsafe {
         let mut inp = helper::convert_buffer_to_gmpz(ciphertext);
         let mut buf = vec![0u8; public.modulo_bytes];
@@ -333,7 +322,7 @@ pub fn decrypt_pkcs1_insecure<R: Random>(
             buf.truncate(buf_len);
             Ok(buf.into())
         } else {
-            Err(Error::DecryptionFailed.into())
+            Err(Error::DecryptionFailed)
         }
     }
 }
